django-caviar - Protect personal data in logs and Django templates
==================================================================

*django-caviar* allows you to protect personal data in Django models and logs.

*django-caviar* is hosted on Github at https://github.com/polyconseil/django-caviar.

Installation
============

(SOON) Install the package from PyPi, using pip:

.. code-block:: sh

    pip install django-caviar

Or from GitHub:

.. code-block:: sh

    git clone git://github.com/Polyconseil/django-caviar

